pub fn live_slice_hashes<'a>(
manifests: impl IntoIterator<Item = &'a Manifest>,
) -> BTreeSet<ContentHash>Expand description
The mark set: every slice hash referenced by any of the manifests.
pub fn live_slice_hashes<'a>(
manifests: impl IntoIterator<Item = &'a Manifest>,
) -> BTreeSet<ContentHash>The mark set: every slice hash referenced by any of the manifests.