GcReport

Struct GcReport 

pub struct GcReport {
    pub freed: Vec<ContentHash>,
    pub retained: usize,
}
What a GC sweep did.

Fields

freed: Vec<ContentHash>

Hashes of blobs deleted because no live manifest referenced them.

retained: usize

Count of blobs kept because they are still referenced.