Reconciliation

Struct Reconciliation 

pub struct Reconciliation {
    pub added: Vec<String>,
    pub modified: Vec<String>,
    pub deleted: Vec<String>,
    pub manifest: Manifest,
}
The result of reconciling a Manifest against a working tree: the change sets (each sorted) plus the reconciled manifest, which equals the tree.

Fields

added: Vec<String>

Paths present in the tree but not the old manifest.

modified: Vec<String>

Paths in both whose content hash changed.

deleted: Vec<String>

Paths in the old manifest but no longer in the tree.

manifest: Manifest

The manifest after reconciliation (equal to the desired tree set).